@@ -10,6 +10,7 @@ import (
 	"time"
 
 	"github.com/PuerkitoBio/goquery"
+	"github.com/go-rod/rod"
 	"github.com/go-rod/rod/lib/proto"
 	"github.com/projectdiscovery/gologger"
 	"github.com/projectdiscovery/katana/pkg/engine/common"
@@ -35,6 +36,7 @@ func (c *Crawler) navigateRequest(s *common.CrawlSession, request *navigation.Re
 		return nil, errorutil.NewWithTag("hybrid", "could not create target").Wrap(err)
 	}
 	defer page.Close()
+	c.addHeadersToPage(page)
 
 	pageRouter := NewHijack(page)
 	pageRouter.SetPattern(&proto.FetchRequestPattern{
@@ -61,6 +63,13 @@ func (c *Crawler) navigateRequest(s *common.CrawlSession, request *navigation.Re
 			statucCodeText = http.StatusText(statusCode)
 		}
 		httpreq, _ := http.NewRequest(e.Request.Method, URL.String(), strings.NewReader(e.Request.PostData))
+		// Note: headers are originally sent using `c.addHeadersToPage` below changes are done so that
+		// headers are reflected in request dump
+		if httpreq != nil {
+			for k, v := range c.Headers {
+				httpreq.Header.Set(k, v)
+			}
+		}
 		httpresp := &http.Response{
 			Proto:         "HTTP/1.1",
 			ProtoMajor:    1,
@@ -154,6 +163,10 @@ func (c *Crawler) navigateRequest(s *common.CrawlSession, request *navigation.Re
 	if err != nil {
 		return nil, errorutil.NewWithTag("hybrid", "url could not be parsed").Wrap(err)
 	}
+
+	if response.Resp == nil {
+		return nil, errorutil.NewWithTag("hybrid", "response is nil").Wrap(err)
+	}
 	response.Resp.Request.URL = parsed.URL
 
 	// Create a copy of intrapolated shadow DOM elements and parse them separately
@@ -175,6 +188,21 @@ func (c *Crawler) navigateRequest(s *common.CrawlSession, request *navigation.Re
 	return response, nil
 }
 
+func (c *Crawler) addHeadersToPage(page *rod.Page) {
+	if len(c.Headers) == 0 {
+		return
+	}
+	var arr []string
+	for k, v := range c.Headers {
+		arr = append(arr, k, v)
+	}
+	// ignore cleanup callback
+	_, err := page.SetExtraHeaders(arr)
+	if err != nil {
+		gologger.Error().Msgf("headless: could not set extra headers: %v", err)
+	}
+}
+
 // traverseDOMNode performs traversal of node completely building a pseudo-HTML
 // from it including the Shadow DOM, Pseudo elements and other children.
 //
